%define uname   MangoHud
%define uversion 0.7.2
%define srcname %{uname}-v%{uversion}
%define rdnsname io.github.flightlessmango.mangohud

Name:           mangohud
Version:        0.7.2
Release:        %mkrel 2
Summary:        A Vulkan overlay layer for monitoring FPS, temperatures, CPU/GPU load and more
Group:          System/Libraries
License:        MIT
URL:            https://github.com/flightlessmango/MangoHud
# DFSG tarball excludes nonfree nvml.h
Source0:        https://github.com/flightlessmango/MangoHud/releases/download/v%{uversion}/%{srcname}-Source-DFSG.tar.xz

BuildRequires:  appstream
BuildRequires:  glslang
BuildRequires:  meson
BuildRequires:  libstdc++-static-devel
BuildRequires:  pkgconfig(cmocka)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  python3dist(mako)

Requires:       %{_lib}vulkan-loader1

Provides:       bundled(imgui)
Provides:       bundled(vulkan-headers)

%description
A Vulkan overlay layer for monitoring FPS, temperatures, CPU/GPU load and more.

To enable the MangoHud Vulkan overlay layer, set `MANGOHUD=1` in the shell,
or use the `mangohud` command to launch programs.
See '%{_docdir}/%{name}' for configuration details.

The `goverlay` package provides a third-party GUI frontend for MangoHud.

%prep
%autosetup -p1 -n %{srcname}

%build
%meson \
  -Dmangoapp=true \
  -Dmangoapp_layer=true \
  -Dmangohudctl=true \
  -Dinclude_doc=true \
  -Duse_system_spdlog=enabled \
  -Dwith_wayland=enabled \
  -Dwith_nvml=disabled \
  -Dwith_xnvctrl=disabled
# NVML is nonfree, XNVCtrl is not packaged yet (but could be enabled if it is)

%meson_build

%install
%meson_install

# Handled below. We still need -Dinclude_doc which governs other desktop data.
rm -rf %{buildroot}%{_docdir}

# python shebang
%py3_shebang_fix %{buildroot}%{_bindir}/mangoplot

%files
%doc README.md data/%{uname}.conf
%license LICENSE
%{_bindir}/%{name}*
%{_bindir}/mangoapp
%{_bindir}/mangoplot
%{_metainfodir}/%{rdnsname}.metainfo.xml
%{_datadir}/vulkan/implicit_layer.d/*Mango*.json
%{_iconsdir}/hicolor/scalable/apps/%{rdnsname}.svg
%{_libdir}/%{name}/
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/mangoapp.1.*


%changelog
* Wed Oct 02 2024 daviddavid <daviddavid> 0.7.2-2.mga10
+ Revision: 2102460
- rebuild for new fmt 11.0.2

* Mon Jun 03 2024 daviddavid <daviddavid> 0.7.2-1.mga10
+ Revision: 2069582
- new version: 0.7.2

* Wed May 08 2024 wally <wally> 0.7.1-2.mga10
+ Revision: 2062880
- rebuild for spdlog 1.14.1

* Mon Apr 01 2024 daviddavid <daviddavid> 0.7.1-1.mga10
+ Revision: 2053673
- new version: 0.7.1

* Sat Feb 10 2024 daviddavid <daviddavid> 0.6.8-3.mga10
+ Revision: 2040065
- rebuild for new spdlog

* Wed Sep 06 2023 papoteur <papoteur> 0.6.8-2.mga10
+ Revision: 1984860
- rebuid for spdlog 1.12

* Thu Nov 03 2022 akien <akien> 0.6.8-1.mga9
+ Revision: 1901970
- Version 0.6.8

* Thu Oct 13 2022 papoteur <papoteur> 0.6.7.1-2.mga9
+ Revision: 1896739
- Rebuild for libfmt 9.1.0

* Mon Jun 13 2022 akien <akien> 0.6.7.1-1.mga9
+ Revision: 1864301
- Version 0.6.7.1

* Fri Mar 25 2022 akien <akien> 0.6.6.1-1.mga9
+ Revision: 1825830
- Version 0.6.6-1

* Fri Mar 25 2022 akien <akien> 0.6.5-1.mga9
+ Revision: 1825777
- Version 0.6.5

* Wed Dec 30 2020 akien <akien> 0.6.1-1.mga8
+ Revision: 1665672
- Version 0.6.1

* Fri Oct 23 2020 akien <akien> 0.5.1-1.mga8
+ Revision: 1638865
- Version 0.5.1
- Require vulkan-loader lib explicitly

* Thu Jun 11 2020 akien <akien> 0.4.1-1.mga8
+ Revision: 1592504
- Version 0.4.1

* Fri Feb 14 2020 akien <akien> 0.2.0-1.mga8
+ Revision: 1519991
- imported package mangohud

